Class: Google::Cloud::DataLabeling::V1beta1::AnnotatedDatasetMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb

Overview

Metadata on AnnotatedDataset.

Instance Attribute Summary collapse

Instance Attribute Details

#bounding_poly_config::Google::Cloud::DataLabeling::V1beta1::BoundingPolyConfig

Returns Configuration for image bounding box and bounding poly task.

Note: The following fields are mutually exclusive: bounding_poly_config, image_classification_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::BoundingPolyConfig)

    Configuration for image bounding box and bounding poly task.

    Note: The following fields are mutually exclusive: bounding_poly_config, image_classification_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#event_config::Google::Cloud::DataLabeling::V1beta1::EventConfig

Returns Configuration for video event labeling task.

Note: The following fields are mutually exclusive: event_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::EventConfig)

    Configuration for video event labeling task.

    Note: The following fields are mutually exclusive: event_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#human_annotation_config::Google::Cloud::DataLabeling::V1beta1::HumanAnnotationConfig

Returns HumanAnnotationConfig used when requesting the human labeling task for this AnnotatedDataset.

Returns:



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_classification_config::Google::Cloud::DataLabeling::V1beta1::ImageClassificationConfig

Returns Configuration for image classification task.

Note: The following fields are mutually exclusive: image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::ImageClassificationConfig)

    Configuration for image classification task.

    Note: The following fields are mutually exclusive: image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#object_detection_config::Google::Cloud::DataLabeling::V1beta1::ObjectDetectionConfig

Returns Configuration for video object detection task.

Note: The following fields are mutually exclusive: object_detection_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::ObjectDetectionConfig)

    Configuration for video object detection task.

    Note: The following fields are mutually exclusive: object_detection_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#object_tracking_config::Google::Cloud::DataLabeling::V1beta1::ObjectTrackingConfig

Returns Configuration for video object tracking task.

Note: The following fields are mutually exclusive: object_tracking_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::ObjectTrackingConfig)

    Configuration for video object tracking task.

    Note: The following fields are mutually exclusive: object_tracking_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#polyline_config::Google::Cloud::DataLabeling::V1beta1::PolylineConfig

Returns Configuration for image polyline task.

Note: The following fields are mutually exclusive: polyline_config, image_classification_config, bounding_poly_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::PolylineConfig)

    Configuration for image polyline task.

    Note: The following fields are mutually exclusive: polyline_config, image_classification_config, bounding_poly_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#segmentation_config::Google::Cloud::DataLabeling::V1beta1::SegmentationConfig

Returns Configuration for image segmentation task.

Note: The following fields are mutually exclusive: segmentation_config, image_classification_config, bounding_poly_config, polyline_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::SegmentationConfig)

    Configuration for image segmentation task.

    Note: The following fields are mutually exclusive: segmentation_config, image_classification_config, bounding_poly_config, polyline_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_classification_config::Google::Cloud::DataLabeling::V1beta1::TextClassificationConfig

Returns Configuration for text classification task.

Note: The following fields are mutually exclusive: text_classification_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::TextClassificationConfig)

    Configuration for text classification task.

    Note: The following fields are mutually exclusive: text_classification_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_entity_extraction_config::Google::Cloud::DataLabeling::V1beta1::TextEntityExtractionConfig

Returns Configuration for text entity extraction task.

Note: The following fields are mutually exclusive: text_entity_extraction_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::TextEntityExtractionConfig)

    Configuration for text entity extraction task.

    Note: The following fields are mutually exclusive: text_entity_extraction_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, video_classification_config, object_detection_config, object_tracking_config, event_config, text_classification_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#video_classification_config::Google::Cloud::DataLabeling::V1beta1::VideoClassificationConfig

Returns Configuration for video classification task.

Note: The following fields are mutually exclusive: video_classification_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::VideoClassificationConfig)

    Configuration for video classification task.

    Note: The following fields are mutually exclusive: video_classification_config, image_classification_config, bounding_poly_config, polyline_config, segmentation_config, object_detection_config, object_tracking_config, event_config, text_classification_config, text_entity_extraction_config. If a field in that set is populated, all other fields in the set will automatically be cleared.



341
342
343
344
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 341

class AnnotatedDatasetMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end