Class: Google::Cloud::DataLabeling::V1beta1::AnnotationSpec
- Inherits:
-
Object
- Object
- Google::Cloud::DataLabeling::V1beta1::AnnotationSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb
Overview
Container of information related to one possible annotation that can be used
in a labeling task. For example, an image classification task where images
are labeled as dog or cat must reference an AnnotationSpec for dog and
an AnnotationSpec for cat.
Instance Attribute Summary collapse
-
#description ⇒ ::String
Optional.
-
#display_name ⇒ ::String
Required.
Instance Attribute Details
#description ⇒ ::String
Returns Optional. User-provided description of the annotation specification. The description can be up to 10,000 characters long.
64 65 66 67 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb', line 64 class AnnotationSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Required. The display name of the AnnotationSpec. Maximum of 64 characters.
64 65 66 67 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb', line 64 class AnnotationSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |