Class: Google::Cloud::DataLabeling::V1beta1::AnnotationSpecSet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb

Overview

An AnnotationSpecSet is a collection of label definitions. For example, in image classification tasks, you define a set of possible labels for images as an AnnotationSpecSet. An AnnotationSpecSet is immutable upon creation.

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_specs::Array<::Google::Cloud::DataLabeling::V1beta1::AnnotationSpec>



48
49
50
51
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb', line 48

class AnnotationSpecSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#blocking_resources::Array<::String>



48
49
50
51
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb', line 48

class AnnotationSpecSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String



48
49
50
51
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb', line 48

class AnnotationSpecSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#display_name::String



48
49
50
51
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb', line 48

class AnnotationSpecSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String



48
49
50
51
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation_spec_set.rb', line 48

class AnnotationSpecSet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end