Class: Google::Cloud::DataLabeling::V1beta1::Example
- Inherits:
-
Object
- Object
- Google::Cloud::DataLabeling::V1beta1::Example
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb
Overview
An Example is a piece of data and its annotation. For example, an image with label "house".
Instance Attribute Summary collapse
-
#annotations ⇒ ::Array<::Google::Cloud::DataLabeling::V1beta1::Annotation>
Output only.
-
#image_payload ⇒ ::Google::Cloud::DataLabeling::V1beta1::ImagePayload
The image payload, a container of the image bytes/uri.
-
#name ⇒ ::String
Output only.
-
#text_payload ⇒ ::Google::Cloud::DataLabeling::V1beta1::TextPayload
The text payload, a container of the text content.
-
#video_payload ⇒ ::Google::Cloud::DataLabeling::V1beta1::VideoPayload
The video payload, a container of the video uri.
Instance Attribute Details
#annotations ⇒ ::Array<::Google::Cloud::DataLabeling::V1beta1::Annotation>
372 373 374 375 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 372 class Example include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#image_payload ⇒ ::Google::Cloud::DataLabeling::V1beta1::ImagePayload
372 373 374 375 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 372 class Example include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
372 373 374 375 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 372 class Example include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text_payload ⇒ ::Google::Cloud::DataLabeling::V1beta1::TextPayload
372 373 374 375 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 372 class Example include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#video_payload ⇒ ::Google::Cloud::DataLabeling::V1beta1::VideoPayload
372 373 374 375 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 372 class Example include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |