Class: Google::Cloud::DataLabeling::V1beta1::InputConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DataLabeling::V1beta1::InputConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb
Overview
The configuration of input data, including data type, location, etc.
Instance Attribute Summary collapse
-
#annotation_type ⇒ ::Google::Cloud::DataLabeling::V1beta1::AnnotationType
Optional.
-
#bigquery_source ⇒ ::Google::Cloud::DataLabeling::V1beta1::BigQuerySource
Source located in BigQuery.
-
#classification_metadata ⇒ ::Google::Cloud::DataLabeling::V1beta1::ClassificationMetadata
Optional.
-
#data_type ⇒ ::Google::Cloud::DataLabeling::V1beta1::DataType
Required.
-
#gcs_source ⇒ ::Google::Cloud::DataLabeling::V1beta1::GcsSource
Source located in Cloud Storage.
-
#text_metadata ⇒ ::Google::Cloud::DataLabeling::V1beta1::TextMetadata
Required for text import, as language code must be specified.
Instance Attribute Details
#annotation_type ⇒ ::Google::Cloud::DataLabeling::V1beta1::AnnotationType
81 82 83 84 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 81 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bigquery_source ⇒ ::Google::Cloud::DataLabeling::V1beta1::BigQuerySource
81 82 83 84 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 81 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#classification_metadata ⇒ ::Google::Cloud::DataLabeling::V1beta1::ClassificationMetadata
81 82 83 84 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 81 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#data_type ⇒ ::Google::Cloud::DataLabeling::V1beta1::DataType
81 82 83 84 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 81 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_source ⇒ ::Google::Cloud::DataLabeling::V1beta1::GcsSource
81 82 83 84 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 81 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#text_metadata ⇒ ::Google::Cloud::DataLabeling::V1beta1::TextMetadata
81 82 83 84 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 81 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |