Class: Google::Cloud::DataLabeling::V1beta1::LabelOperationMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datalabeling/v1beta1/operations.rb

Overview

Metadata of a labeling operation, such as LabelImage or LabelVideo. Next tag: 20

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp

Returns Output only. Timestamp when labeling request was created.

Returns:



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_bounding_box_details::Google::Cloud::DataLabeling::V1beta1::LabelImageBoundingBoxOperationMetadata

Returns Details of label image bounding box operation.

Note: The following fields are mutually exclusive: image_bounding_box_details, image_classification_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelImageBoundingBoxOperationMetadata)

    Details of label image bounding box operation.

    Note: The following fields are mutually exclusive: image_bounding_box_details, image_classification_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_bounding_poly_details::Google::Cloud::DataLabeling::V1beta1::LabelImageBoundingPolyOperationMetadata

Returns Details of label image bounding poly operation.

Note: The following fields are mutually exclusive: image_bounding_poly_details, image_classification_details, image_bounding_box_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelImageBoundingPolyOperationMetadata)

    Details of label image bounding poly operation.

    Note: The following fields are mutually exclusive: image_bounding_poly_details, image_classification_details, image_bounding_box_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_classification_details::Google::Cloud::DataLabeling::V1beta1::LabelImageClassificationOperationMetadata

Returns Details of label image classification operation.

Note: The following fields are mutually exclusive: image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelImageClassificationOperationMetadata)

    Details of label image classification operation.

    Note: The following fields are mutually exclusive: image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_oriented_bounding_box_details::Google::Cloud::DataLabeling::V1beta1::LabelImageOrientedBoundingBoxOperationMetadata

Returns Details of label image oriented bounding box operation.

Note: The following fields are mutually exclusive: image_oriented_bounding_box_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelImageOrientedBoundingBoxOperationMetadata)

    Details of label image oriented bounding box operation.

    Note: The following fields are mutually exclusive: image_oriented_bounding_box_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_polyline_details::Google::Cloud::DataLabeling::V1beta1::LabelImagePolylineOperationMetadata

Returns Details of label image polyline operation.

Note: The following fields are mutually exclusive: image_polyline_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelImagePolylineOperationMetadata)

    Details of label image polyline operation.

    Note: The following fields are mutually exclusive: image_polyline_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#image_segmentation_details::Google::Cloud::DataLabeling::V1beta1::LabelImageSegmentationOperationMetadata

Returns Details of label image segmentation operation.

Note: The following fields are mutually exclusive: image_segmentation_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelImageSegmentationOperationMetadata)

    Details of label image segmentation operation.

    Note: The following fields are mutually exclusive: image_segmentation_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#partial_failures::Array<::Google::Rpc::Status>

Returns Output only. Partial failures encountered. E.g. single files that couldn't be read. Status details field will contain standard GCP error details.

Returns:

  • (::Array<::Google::Rpc::Status>)

    Output only. Partial failures encountered. E.g. single files that couldn't be read. Status details field will contain standard GCP error details.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#progress_percent::Integer

Returns Output only. Progress of label operation. Range: [0, 100].

Returns:

  • (::Integer)

    Output only. Progress of label operation. Range: [0, 100].



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_classification_details::Google::Cloud::DataLabeling::V1beta1::LabelTextClassificationOperationMetadata

Returns Details of label text classification operation.

Note: The following fields are mutually exclusive: text_classification_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelTextClassificationOperationMetadata)

    Details of label text classification operation.

    Note: The following fields are mutually exclusive: text_classification_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#text_entity_extraction_details::Google::Cloud::DataLabeling::V1beta1::LabelTextEntityExtractionOperationMetadata

Returns Details of label text entity extraction operation.

Note: The following fields are mutually exclusive: text_entity_extraction_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelTextEntityExtractionOperationMetadata)

    Details of label text entity extraction operation.

    Note: The following fields are mutually exclusive: text_entity_extraction_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#video_classification_details::Google::Cloud::DataLabeling::V1beta1::LabelVideoClassificationOperationMetadata

Returns Details of label video classification operation.

Note: The following fields are mutually exclusive: video_classification_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelVideoClassificationOperationMetadata)

    Details of label video classification operation.

    Note: The following fields are mutually exclusive: video_classification_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_object_detection_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#video_event_details::Google::Cloud::DataLabeling::V1beta1::LabelVideoEventOperationMetadata

Returns Details of label video event operation.

Note: The following fields are mutually exclusive: video_event_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelVideoEventOperationMetadata)

    Details of label video event operation.

    Note: The following fields are mutually exclusive: video_event_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_object_tracking_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#video_object_detection_details::Google::Cloud::DataLabeling::V1beta1::LabelVideoObjectDetectionOperationMetadata

Returns Details of label video object detection operation.

Note: The following fields are mutually exclusive: video_object_detection_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelVideoObjectDetectionOperationMetadata)

    Details of label video object detection operation.

    Note: The following fields are mutually exclusive: video_object_detection_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_tracking_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#video_object_tracking_details::Google::Cloud::DataLabeling::V1beta1::LabelVideoObjectTrackingOperationMetadata

Returns Details of label video object tracking operation.

Note: The following fields are mutually exclusive: video_object_tracking_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::LabelVideoObjectTrackingOperationMetadata)

    Details of label video object tracking operation.

    Note: The following fields are mutually exclusive: video_object_tracking_details, image_classification_details, image_bounding_box_details, image_bounding_poly_details, image_oriented_bounding_box_details, image_polyline_details, image_segmentation_details, video_classification_details, video_object_detection_details, video_event_details, text_classification_details, text_entity_extraction_details. If a field in that set is populated, all other fields in the set will automatically be cleared.



170
171
172
173
# File 'proto_docs/google/cloud/datalabeling/v1beta1/operations.rb', line 170

class LabelOperationMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end