Class: Google::Cloud::DataLabeling::V1beta1::LabelStats
- Inherits:
-
Object
- Object
- Google::Cloud::DataLabeling::V1beta1::LabelStats
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb
Overview
Statistics about annotation specs.
Defined Under Namespace
Classes: ExampleCountEntry
Instance Attribute Summary collapse
-
#example_count ⇒ ::Google::Protobuf::Map{::String => ::Integer}
Map of each annotation spec's example count.
Instance Attribute Details
#example_count ⇒ ::Google::Protobuf::Map{::String => ::Integer}
Returns Map of each annotation spec's example count. Key is the annotation spec name and value is the number of examples for that annotation spec. If the annotated dataset does not have annotation spec, the map will return a pair where the key is empty string and value is the total number of annotations.
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 272 class LabelStats include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Integer] class ExampleCountEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |