Class: Google::Cloud::DataLabeling::V1beta1::OperatorMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datalabeling/v1beta1/annotation.rb

Overview

General information useful for labels coming from contributors.

Instance Attribute Summary collapse

Instance Attribute Details

#comments::Array<::String>

Returns Comments from contributors.

Returns:

  • Comments from contributors.



360
361
362
363
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation.rb', line 360

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#label_votes::Integer

Returns The total number of contributors that choose this label.

Returns:

  • The total number of contributors that choose this label.



360
361
362
363
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation.rb', line 360

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#score::Float

Returns Confidence score corresponding to a label. For examle, if 3 contributors have answered the question and 2 of them agree on the final label, the confidence score will be 0.67 (2/3).

Returns:

  • Confidence score corresponding to a label. For examle, if 3 contributors have answered the question and 2 of them agree on the final label, the confidence score will be 0.67 (2/3).



360
361
362
363
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation.rb', line 360

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#total_votes::Integer

Returns The total number of contributors that answer this question.

Returns:

  • The total number of contributors that answer this question.



360
361
362
363
# File 'proto_docs/google/cloud/datalabeling/v1beta1/annotation.rb', line 360

class 
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end