Class: Google::Cloud::DataLabeling::V1beta1::OutputConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb

Overview

The configuration of output data.

Instance Attribute Summary collapse

Instance Attribute Details

#gcs_destination::Google::Cloud::DataLabeling::V1beta1::GcsDestination

Returns Output to a file in Cloud Storage. Should be used for labeling output other than image segmentation.

Note: The following fields are mutually exclusive: gcs_destination, gcs_folder_destination. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::GcsDestination)

    Output to a file in Cloud Storage. Should be used for labeling output other than image segmentation.

    Note: The following fields are mutually exclusive: gcs_destination, gcs_folder_destination. If a field in that set is populated, all other fields in the set will automatically be cleared.



160
161
162
163
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 160

class OutputConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gcs_folder_destination::Google::Cloud::DataLabeling::V1beta1::GcsFolderDestination

Returns Output to a folder in Cloud Storage. Should be used for image segmentation labeling output.

Note: The following fields are mutually exclusive: gcs_folder_destination, gcs_destination. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::DataLabeling::V1beta1::GcsFolderDestination)

    Output to a folder in Cloud Storage. Should be used for image segmentation labeling output.

    Note: The following fields are mutually exclusive: gcs_folder_destination, gcs_destination. If a field in that set is populated, all other fields in the set will automatically be cleared.



160
161
162
163
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 160

class OutputConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end