Class: Google::Cloud::DataLabeling::V1beta1::PrCurve::ConfidenceMetricsEntry
- Inherits:
-
Object
- Object
- Google::Cloud::DataLabeling::V1beta1::PrCurve::ConfidenceMetricsEntry
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb
Instance Attribute Summary collapse
-
#confidence_threshold ⇒ ::Float
Threshold used for this entry.
-
#f1_score ⇒ ::Float
Harmonic mean of recall and precision.
-
#f1_score_at1 ⇒ ::Float
The harmonic mean of recall_at1 and precision_at1.
-
#f1_score_at5 ⇒ ::Float
The harmonic mean of recall_at5 and precision_at5.
-
#precision ⇒ ::Float
Precision value.
-
#precision_at1 ⇒ ::Float
Precision value for entries with label that has highest score.
-
#precision_at5 ⇒ ::Float
Precision value for entries with label that has highest 5 scores.
-
#recall ⇒ ::Float
Recall value.
-
#recall_at1 ⇒ ::Float
Recall value for entries with label that has highest score.
-
#recall_at5 ⇒ ::Float
Recall value for entries with label that has highest 5 scores.
Instance Attribute Details
#confidence_threshold ⇒ ::Float
Returns Threshold used for this entry.
For classification tasks, this is a classification threshold: a predicted label is categorized as positive or negative (in the context of this point on the PR curve) based on whether the label's score meets this threshold.
For image object detection (bounding box) tasks, this is the [intersection-over-union
(IOU)](/vision/automl/object-detection/docs/evaluate#intersection-over-union) threshold for the context of this point on the PR curve.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#f1_score ⇒ ::Float
Returns Harmonic mean of recall and precision.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#f1_score_at1 ⇒ ::Float
Returns The harmonic mean of recall_at1 and precision_at1.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#f1_score_at5 ⇒ ::Float
Returns The harmonic mean of recall_at5 and precision_at5.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#precision ⇒ ::Float
Returns Precision value.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#precision_at1 ⇒ ::Float
Returns Precision value for entries with label that has highest score.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#precision_at5 ⇒ ::Float
Returns Precision value for entries with label that has highest 5 scores.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recall ⇒ ::Float
Returns Recall value.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recall_at1 ⇒ ::Float
Returns Recall value for entries with label that has highest score.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recall_at5 ⇒ ::Float
Returns Recall value for entries with label that has highest 5 scores.
183 184 185 186 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 183 class ConfidenceMetricsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |