Class: Google::Cloud::DataLabeling::V1beta1::SentimentConfig
- Inherits:
-
Object
- Object
- Google::Cloud::DataLabeling::V1beta1::SentimentConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datalabeling/v1beta1/human_annotation_config.rb
Overview
Config for setting up sentiments.
Instance Attribute Summary collapse
-
#enable_label_sentiment_selection ⇒ ::Boolean
If set to true, contributors will have the option to select sentiment of the label they selected, to mark it as negative or positive label.
Instance Attribute Details
#enable_label_sentiment_selection ⇒ ::Boolean
219 220 221 222 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/human_annotation_config.rb', line 219 class SentimentConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |