Class: Google::Cloud::DataLabeling::V1beta1::VideoClassificationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/datalabeling/v1beta1/human_annotation_config.rb

Overview

Config for video classification human labeling task. Currently two types of video classification are supported:

  1. Assign labels on the entire video.
  2. Split the video into multiple video clips based on camera shot, and assign labels on each video clip.

Defined Under Namespace

Classes: AnnotationSpecSetConfig

Instance Attribute Summary collapse

Instance Attribute Details

#annotation_spec_set_configs::Array<::Google::Cloud::DataLabeling::V1beta1::VideoClassificationConfig::AnnotationSpecSetConfig>



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'proto_docs/google/cloud/datalabeling/v1beta1/human_annotation_config.rb', line 143

class VideoClassificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Annotation spec set with the setting of allowing multi labels or not.
  # @!attribute [rw] annotation_spec_set
  #   @return [::String]
  #     Required. Annotation spec set resource name.
  # @!attribute [rw] allow_multi_label
  #   @return [::Boolean]
  #     Optional. If allow_multi_label is true, contributors are able to
  #     choose multiple labels from one annotation spec set.
  class AnnotationSpecSetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#apply_shot_detection::Boolean



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'proto_docs/google/cloud/datalabeling/v1beta1/human_annotation_config.rb', line 143

class VideoClassificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Annotation spec set with the setting of allowing multi labels or not.
  # @!attribute [rw] annotation_spec_set
  #   @return [::String]
  #     Required. Annotation spec set resource name.
  # @!attribute [rw] allow_multi_label
  #   @return [::Boolean]
  #     Optional. If allow_multi_label is true, contributors are able to
  #     choose multiple labels from one annotation spec set.
  class AnnotationSpecSetConfig
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end