Class: Google::Cloud::DataLabeling::V1beta1::BigQuerySource
- Inherits:
-
Object
- Object
- Google::Cloud::DataLabeling::V1beta1::BigQuerySource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb
Overview
The BigQuery location for input data. If used in an EvaluationJob, this is where the service saves the prediction input and output sampled from the model version.
Instance Attribute Summary collapse
-
#input_uri ⇒ ::String
Required.
Instance Attribute Details
#input_uri ⇒ ::String
138 139 140 141 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/dataset.rb', line 138 class BigQuerySource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |