Class: Google::Cloud::DataLabeling::V1beta1::EvaluationMetrics
- Inherits:
-
Object
- Object
- Google::Cloud::DataLabeling::V1beta1::EvaluationMetrics
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb
Instance Attribute Summary collapse
-
#classification_metrics ⇒ ::Google::Cloud::DataLabeling::V1beta1::ClassificationMetrics
Note: The following fields are mutually exclusive:
classification_metrics,object_detection_metrics. -
#object_detection_metrics ⇒ ::Google::Cloud::DataLabeling::V1beta1::ObjectDetectionMetrics
Note: The following fields are mutually exclusive:
object_detection_metrics,classification_metrics.
Instance Attribute Details
#classification_metrics ⇒ ::Google::Cloud::DataLabeling::V1beta1::ClassificationMetrics
Returns Note: The following fields are mutually exclusive: classification_metrics, object_detection_metrics. If a field in that set is populated, all other fields in the set will automatically be cleared.
95 96 97 98 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 95 class EvaluationMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#object_detection_metrics ⇒ ::Google::Cloud::DataLabeling::V1beta1::ObjectDetectionMetrics
Returns Note: The following fields are mutually exclusive: object_detection_metrics, classification_metrics. If a field in that set is populated, all other fields in the set will automatically be cleared.
95 96 97 98 |
# File 'proto_docs/google/cloud/datalabeling/v1beta1/evaluation.rb', line 95 class EvaluationMetrics include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |